#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 keys
version:              3.12.3
visibility:           public
id:                   keys-3.12.3-8KSpkQJsgmd9mHbH8OuRcZ
key:                  keys-3.12.3-8KSpkQJsgmd9mHbH8OuRcZ
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  3f98ad2ee835c213342fd5bed14a70a0
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-8.10.5/site-local/keys-3.12.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/keys-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/keys-3.12.3
hs-libraries:         HSkeys-3.12.3-8KSpkQJsgmd9mHbH8OuRcZ
depends:
    array-0.5.4.0 base-4.14.2.0 comonad-5.0.8-8a10YHmXJVq2BoDg3RtKOL
    containers-0.6.4.1 free-5.1.7-G4cc1Y718fXDuPxii9x6Pg
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    semigroupoids-5.3.5-1MUCoMhFnfRKlT8x21E1a0
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

